@@ -36,56 +36,23 @@ if ( __PACKAGE__->config->{function_on}->{page_cache} ) {
     }
 }
 
-{
-    use Sub::Install;
+## set $c->language before create a key in PageCache
+__PACKAGE__->config->{'Plugin::PageCache'}->{key_maker} = sub {
+    my $c = shift;
 
-    # rewrite _get_page_cache_key in C::A::PageCache for own use
-    my $_get_page_cache_key = sub {
-        my $c = shift;
+    # something as the same as in Root.pm
+    # while it is called before we call sub auto in Root.pm
+    # and we may not call this if request doesn't call $c->cache_page
+    my $lang;
+    $lang = $c->req->cookie('lang')->value if ( $c->req->cookie('lang') );
+    $lang ||= $c->user->lang if ( $c->user_exists );
+    $lang ||= $c->config->{default_lang};
+    $lang = $c->req->param('lang') if ( $c->req->param('lang') );
+    $lang =~ s/\W+//isg;
+    $c->languages( [$lang] );
 
-        # We can't rely on the params after the user's code has run, so
-        # use the key created during the initial dispatch phase
-        return $c->_page_cache_key if ( $c->_page_cache_key );
-
-        my $key = "/" . $c->req->path;
-
-        # Change Start
-        my $lang;
-        $lang = $c->req->cookie('lang')->value if ( $c->req->cookie('lang') );
-        $lang ||= $c->user->lang if ( $c->user_exists );
-        $lang ||= $c->config->{default_lang};
-        $lang = $c->req->param('lang') if ( $c->req->param('lang') );
-        $lang =~ s/\W+//isg;
-        $key .= ':' . $lang;
-
-        # Change End
-
-        if ( scalar $c->req->param ) {
-            my @params;
-            foreach my $arg ( sort keys %{ $c->req->params } ) {
-                if ( ref $c->req->params->{$arg} ) {
-                    my $list = $c->req->params->{$arg};
-                    push @params, map { "$arg=" . $_ } sort @{$list};
-                } else {
-                    push @params, "$arg=" . $c->req->params->{$arg};
-                }
-            }
-            $key .= '?' . join( '&', @params );
-        } elsif ( my $query = $c->req->uri->query ) {
-            $key .= '?' . $query;
-        }
-
-        $c->_page_cache_key($key);
-
-        return $key;
-    };
-    Sub::Install::install_sub(
-        {   code => $_get_page_cache_key,
-            into => 'Catalyst::Plugin::PageCache',
-            as   => '_get_page_cache_key'
-        }
-    );
-}
+    return "/" . $c->req->path;
+};
 
 1;
 __END__
@@ -124,7 +91,7 @@ use L<Cache::Memcached> or use L<Cache::FileCache> or others;
 
 =item reliable job queue
 
-use L<TheSchwartz>
+use L<TheSchwartz::Simple>, L<MooseX::TheSchwartz>
 
 =item Multi Formatter
 
