@@ -3,14 +3,13 @@ package Foorum::TheSchwartz::Worker::SendStarredNofication;
 use strict;
 use warnings;
 use Foorum::Version; our $VERSION = $Foorum::VERSION;
-use TheSchwartz::Job;
-use base qw( TheSchwartz::Worker );
+use base qw( MooseX::TheSchwartz::Worker );
 use Foorum::SUtils qw/schema/;
 use Foorum::XUtils qw/config base_path cache/;
 
 sub work {
     my $class = shift;
-    my TheSchwartz::Job $job = shift;
+    my $job   = shift;
 
     my ($args) = $job->arg;
     my ( $object_type, $object_id, $from_id ) = @$args;
