@@ -3,8 +3,7 @@ package Foorum::TheSchwartz::Worker::Topic_ViewAsPDF;
 use strict;
 use warnings;
 use Foorum::Version; our $VERSION = $Foorum::VERSION;
-use TheSchwartz::Job;
-use base qw( TheSchwartz::Worker );
+use base qw( MooseX::TheSchwartz::Worker );
 use Foorum::SUtils qw/schema/;
 use Foorum::Logger qw/error_log/;
 use Foorum::XUtils qw/config base_path cache tt2/;
@@ -14,7 +13,7 @@ use File::Spec;
 
 sub work {
     my $class = shift;
-    my TheSchwartz::Job $job = shift;
+    my $job   = shift;
 
     my ($args) = $job->arg;
     my ( $forum_id, $topic_id, $random_word ) = @$args;
